searchNodes=[{"ref":"DawdleDB.Handler.html","title":"DawdleDB.Handler","type":"behaviour","doc":"Defines a handler for database events on a single table. To define an event handler, use DawdleDB.Handler and provide a Ecto schema type that you wish to handle. Then, override the callbacks handle_insert/1, handle_update/2, handle_delete/1, as appropriate. Examples defmodule MyApp.TestDBHandler do use DawdleDB.Handler, type: [MyApp.MySchema] alias MyApp.MySchema def handle_insert(%MySchema{} = new) do # Do something... end def handle_update(%MySchema{} = new, old) do # Do something else... end def handle_delete(%MySchema{} = old) do # Default case end end"},{"ref":"DawdleDB.Handler.html#c:handle_delete/1","title":"DawdleDB.Handler.handle_delete/1","type":"callback","doc":"This function is called when DawdleDB pulls a delete event for the specified table from the queue. The function is executed for its side effects and the return value is ignored."},{"ref":"DawdleDB.Handler.html#c:handle_insert/1","title":"DawdleDB.Handler.handle_insert/1","type":"callback","doc":"This function is called when DawdleDB pulls an insert event for the specified table from the queue. The function is executed for its side effects and the return value is ignored."},{"ref":"DawdleDB.Handler.html#c:handle_update/2","title":"DawdleDB.Handler.handle_update/2","type":"callback","doc":"This function is called when DawdleDB pulls an update event for the specified table from the queue. The function is executed for its side effects and the return value is ignored."},{"ref":"DawdleDB.Migration.html","title":"DawdleDB.Migration","type":"module","doc":"Utilities for managing the DawdleDB events table and notification related triggers. Examples defmodule MyApp.DawdleDBSetup do use Ecto.Migration import DawdleDB.Migration def up do create_watcher_events_table() update_notify(&quot;users&quot;, [:insert, :update, :delete]) end def down do remove_notify(&quot;users&quot;, [:insert, :update, :delete]) drop_watcher_events_table() end end"},{"ref":"DawdleDB.Migration.html#create_watcher_events_table/0","title":"DawdleDB.Migration.create_watcher_events_table/0","type":"function","doc":"Creates the DawdleDB watcher events table. This table is necessary for DawdleDB to manage events."},{"ref":"DawdleDB.Migration.html#drop_watcher_events_table/0","title":"DawdleDB.Migration.drop_watcher_events_table/0","type":"function","doc":"Drops the DawdleDB watcher events table."},{"ref":"DawdleDB.Migration.html#remove_notify/2","title":"DawdleDB.Migration.remove_notify/2","type":"function","doc":"Remove event notification function/trigger from a table. Examples remove_notify(&quot;my_table&quot;, [:insert])"},{"ref":"DawdleDB.Migration.html#update_notify/3","title":"DawdleDB.Migration.update_notify/3","type":"function","doc":"Add event notification function/trigger to a table. To override the encoding of particular fields, provide an override with $ITEM$ as the item to be overridden. For example, to override the encoding of the &quot;title&quot; field, use: {&quot;title&quot;, &quot;my_encoding_function($ITEM$)&quot;}. Examples update_notify(&quot;my_table&quot;, [:insert, :update]) update_notify(&quot;other_table&quot;, [:insert], [{&quot;title&quot;, &quot;my_encoding_function($ITEM$)&quot;}])"},{"ref":"DawdleDB.Migration.html#t:override/0","title":"DawdleDB.Migration.override/0","type":"type","doc":""},{"ref":"DawdleDB.Migration.html#t:table/0","title":"DawdleDB.Migration.table/0","type":"type","doc":""},{"ref":"DawdleDB.TestHelper.html","title":"DawdleDB.TestHelper","type":"module","doc":"Helpers for writing tests that exercise the DawdleDB system."},{"ref":"DawdleDB.TestHelper.html#start_watcher/1","title":"DawdleDB.TestHelper.start_watcher/1","type":"function","doc":"Set up the DB watcher/callback system for test cases that require it."},{"ref":"readme.html","title":"DawdleDB","type":"extras","doc":"DawdleDB DawdleDB uses Dawdle and SQS to capture change notifications from PostgreSQL."},{"ref":"readme.html#installation","title":"DawdleDB - Installation","type":"extras","doc":"The package can be installed by adding dawdle_db to your list of dependencies in mix.exs: def deps do [ {:dawdle_db, &quot;~&gt; 0.5.0&quot;} ] end Documentation can be found at https://hexdocs.pm/dawdle_db."},{"ref":"readme.html#usage","title":"DawdleDB - Usage","type":"extras","doc":"DawdleDB can be run in either watcher mode or listener mode. In watcher mode it captures PostgreSQL notifications and encodes them into an Elixir struct which is then posted to SQS. In listener mode, the events are pulled out of SQS and handed off to handlers for processing. For best results, there should only be one instance of DawdleDB running in watcher mode; though you can have many instances running in listener mode. Initial setup DawdleDB relies on database triggers to fire the appropriate notifications. There are helpers defined in DawdleDB.Migration to simplify initial setup and defining the triggers. For example, if you already have a users table and you wish to recieve notifications on insert, update, and delete, you could create a migration like the following: defmodule MyApp.DawdleDBSetup do use Ecto.Migration import DawdleDB.Migration def up do create_watcher_events_table() update_notify(&quot;users&quot;, [:insert, :update, :delete]) end def down do remove_notify(&quot;users&quot;, [:insert, :update, :delete]) drop_watcher_events_table() end end Handlers Once the watcher events table has been created, and triggers have been setup, define a handler based on DawdleDB.Handler. defmodule MyApp.UserHandler do use DawdleDB.Handler, type: MyApp.User alias MyApp.User def handle_insert(%User{} = new) do # Do something when a user is created :ok end def handle_update(%User{} = new, %User{} = old) do # Do something when a user is updated :ok end def handle_delete(%User{} = old) do # Do something when a user is deleted :ok end end"}]